@@ -13,7 +13,6 @@ from flask.views import MethodView
 
 from flask_smorest import Api, Blueprint, Page
 from flask_smorest.fields import Upload
-from flask_smorest.compat import MARSHMALLOW_VERSION_MAJOR
 
 
 from .utils import build_ref
@@ -292,9 +291,6 @@ class TestBlueprint:
         client = app.test_client()
 
         class MultipartSchema(ma.Schema):
-            if MARSHMALLOW_VERSION_MAJOR < 3:
-                class Meta:
-                    strict = True
             file_1 = Upload()
             file_2 = Upload()
 
@@ -419,24 +415,12 @@ class TestBlueprint:
         spec = api.spec.to_dict()
         params = spec['paths']['/test/{item_id}']['parameters']
         assert len(params) == 2
+        assert params[0] == build_ref(api.spec, 'parameter', 'TestParameter')
+        assert params[1]['description'] == 'Item ID'
         if openapi_version == '2.0':
-            assert params == [
-                build_ref(api.spec, 'parameter', 'TestParameter'),
-                {
-                    'name': 'item_id', 'in': 'path', 'required': True,
-                    'description': 'Item ID',
-                    'format': 'int32', 'type': 'integer'
-                },
-            ]
+            assert params[1]['type'] == 'integer'
         else:
-            assert params == [
-                build_ref(api.spec, 'parameter', 'TestParameter'),
-                {
-                    'name': 'item_id', 'in': 'path', 'required': True,
-                    'description': 'Item ID',
-                    'schema': {'format': 'int32', 'type': 'integer'}
-                },
-            ]
+            assert params[1]['schema']['type'] == 'integer'
 
     @pytest.mark.parametrize('as_method_view', (True, False))
     def test_blueprint_route_path_parameter_default(self, app, as_method_view):
@@ -795,9 +779,6 @@ class TestBlueprint:
             'content': {'application/json': {'example': {'test': 123}}}}
 
         class ItemSchema(ma.Schema):
-            if MARSHMALLOW_VERSION_MAJOR < 3:
-                class Meta:
-                    strict = True
             test = ma.fields.Int()
 
         @blp.route('/')
@@ -829,9 +810,6 @@ class TestBlueprint:
         doc_desc = {'description': 'Description'}
 
         class ItemSchema(ma.Schema):
-            if MARSHMALLOW_VERSION_MAJOR < 3:
-                class Meta:
-                    strict = True
             test = ma.fields.Int()
 
         @blp.route('/')
